/*
 * ident.h:
 * lots of OS-specific information for getting the serial numbers
 * of drives, calculating free space, and stuff like that.
 */

#ifndef __IDENT_H__
#define __IDENT_H__

class ident {
private:
    static char *append(char *base,char *add); // append add to base and return the new base
public:;
    ident(int fd);			// ident an open file descriptor
    ident(const char *fn);		// ident a filename or file system
    ~ident();
    
    int fd;
    char *filename;			// filename
    bool opened;			// need to close?

    bool is_scsi();			// return true if scsi
    // scsi variables get set if this is a scsi device
    int  scsi_bus;
    int  scsi_tid;
    int  scsi_lun;
    int  scsi_pass;			// freebsd specific thing

    bool is_ata();
    int  ata_dev;
    int  ata_primary;			// 0 = primary; 1 = secondary
    int  ata_master;			// 0 = master; 1 = slave

    /* General information about the device */
    char device_model[256];
    char serial_number[256];
    char firmware_revision[256];

    unsigned long long freebytes();	// amount of free bytes on device


    /* General functions about the machine */
    static char *mac_addresses();		
    // returns a buffer, which must be freed, of a null-terminated
    // list of ethernet mac addresses in the current computers.

    static char *dmesg();
    // returns a buffer, which must be freed, of a null-terminated
    // string that has the output of the "dmesg" command.
};

#endif

